import { Link, useNavigate } from "react-router-dom";
import styles from "./../assets/css/navigation.module.css";
import { AutoComplete, Input } from "antd";
import { useState, useEffect } from "react";
import { useDispatch } from "react-redux";
import { SearchActions } from "../store/search";

const Navigation = () => {
  const [query, setQuery] = useState("");
  const navigate = useNavigate();
  const dispatch = useDispatch();
  const [options, setOptions] = useState([
    { value: "", label: "Type to search" },
  ]);
  const handleSearch = (value) => {
    setQuery(value);
  };
  const onSelect = (value) => {
    dispatch(SearchActions.setQuery(value));
    navigate(`/recipes?query=${value}`);
  };

  useEffect(() => {
    const timer = setTimeout(async () => {
      if (query) {
        setOptions([{ value: "", label: "Loading..." }]);
        const response = await fetch(
          `https://tasty.p.rapidapi.com/recipes/auto-complete?prefix=${query}`,
          {
            headers: {
              "X-RapidAPI-Key":
                "a144142bc4mshd5814560d376563p1bc61ajsna42f23118976",
              "X-RapidAPI-Host": "tasty.p.rapidapi.com",
            },
          }
        );
        const data = await response.json();
        const parsed = data.results.map((option) => {
          return { value: option.display, label: option.search_value };
        });
        if (parsed.length < 1) {
          setOptions([{ value: "", label: "No results" }]);
        } else {
          setOptions(parsed);
        }
      }
    }, 200);

    return function cleanup() {
      clearTimeout(timer);
    };
  }, [query]);

  return (
    <nav className={styles.navbar}>
      <div className={styles.logo}>
        <Link to="/">Recipe Finder</Link>
      </div>
      <ul className={styles.navLinks}>
        <li>
          <AutoComplete
            style={{
              width: 200,
            }}
            onSearch={handleSearch}
            options={options}
            onSelect={onSelect}
          >
            <Input.Search
              size="large"
              placeholder="Search Recipe"
              enterButton
            />
          </AutoComplete>
        </li>
      </ul>
    </nav>
  );
};

export default Navigation;
