import {
  defer,
  useLoaderData,
  Await,
  json,
  useLocation,
} from "react-router-dom";
import { Suspense } from "react";
import Layout from "../components/Layout";
import { Skeleton } from "antd";
import { useEffect } from "react";
import { Link } from "react-router-dom";
import { BreadCrumbActions } from "../store/breadcrumb";
import { useDispatch, useSelector } from "react-redux";
const Recipes = () => {
  const { recipes } = useLoaderData();
  const dispatch = useDispatch();
  let { query } = useSelector((state) => state.search);
  const location = useLocation();

  if (!query) {
    const searchParams = new URLSearchParams(location.search);
    query = searchParams.get("query");
  }
  useEffect(() => {
    const breadCrumb = [
      {
        title: <Link to="/">Home</Link>,
      },
      {
        title: <Link to={`/recipes?query=${query}`}>{query}</Link>,
      },
    ];
    dispatch(BreadCrumbActions.updateBreadCrumb(breadCrumb));
  }, []);

  return (
    <Suspense
      fallback={
        <>
          <Skeleton />
          <Skeleton />
          <Skeleton />
          <Skeleton />
          <Skeleton />
        </>
      }
    >
      <Await resolve={recipes}>
        {(loadedRecipes) => {
          return <Layout recipes={loadedRecipes.results} />;
        }}
      </Await>
    </Suspense>
  );
};

const FetchRecipes = async (data) => {
  const url = new URL(data.request.url);
  const queryParams = new URLSearchParams(url.search);

  // Access individual query parameters
  const query = queryParams.get("query");
  const response = await fetch(
    `https://tasty.p.rapidapi.com/recipes/list?from=0&size=20&q=${query}`,
    {
      headers: {
        "X-RapidAPI-Key": "a144142bc4mshd5814560d376563p1bc61ajsna42f23118976",
        "X-RapidAPI-Host": "tasty.p.rapidapi.com",
      },
    }
  );
  try {
    if (response.ok) {
      const recipes = await response.json();
      return recipes;
    } else {
      throw json({ message: "Cannot get data from API" }, { status: 500 });
    }
  } catch (error) {
    console.log(error);
  }
};

export const loadRecipes = async (data) => {
  return defer({ recipes: FetchRecipes(data) });
};

export default Recipes;
